==> db-client-java-5.4.3-sources.jar: com/eventstore/dbclient/proto/serverfeatures/ServerFeaturesGrpc.java <==
package com.eventstore.dbclient.proto.serverfeatures;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.61.1)",
    comments = "Source: serverfeatures.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class ServerFeaturesGrpc {

  private ServerFeaturesGrpc() {}

  public static final java.lang.String SERVICE_NAME = "event_store.client.server_features.ServerFeatures";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetSupportedMethods",
      requestType = com.eventstore.dbclient.proto.shared.Shared.Empty.class,
      responseType = com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod() {
    io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod;
    if ((getGetSupportedMethodsMethod = ServerFeaturesGrpc.getGetSupportedMethodsMethod) == null) {
      synchronized (ServerFeaturesGrpc.class) {
        if ((getGetSupportedMethodsMethod = ServerFeaturesGrpc.getGetSupportedMethodsMethod) == null) {
          ServerFeaturesGrpc.getGetSupportedMethodsMethod = getGetSupportedMethodsMethod =
              io.grpc.MethodDescriptor.<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetSupportedMethods"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.shared.Shared.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods.getDefaultInstance()))
              .setSchemaDescriptor(new ServerFeaturesMethodDescriptorSupplier("GetSupportedMethods"))
              .build();
        }
      }
    }
    return getGetSupportedMethodsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ServerFeaturesStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesStub>() {
        @java.lang.Override
        public ServerFeaturesStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesStub(channel, callOptions);
        }
      };
    return ServerFeaturesStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ServerFeaturesBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingStub>() {
        @java.lang.Override
        public ServerFeaturesBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesBlockingStub(channel, callOptions);
        }
      };
    return ServerFeaturesBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ServerFeaturesFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesFutureStub>() {
        @java.lang.Override
        public ServerFeaturesFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesFutureStub(channel, callOptions);
        }
      };
    return ServerFeaturesFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetSupportedMethodsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service ServerFeatures.
   */
  public static abstract class ServerFeaturesImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return ServerFeaturesGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesStub
      extends io.grpc.stub.AbstractAsyncStub<ServerFeaturesStub> {
    private ServerFeaturesStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesStub(channel, callOptions);
    }

    /**
     */
    public void getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetSupportedMethodsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<ServerFeaturesBlockingStub> {
    private ServerFeaturesBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetSupportedMethodsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesFutureStub
      extends io.grpc.stub.AbstractFutureStub<ServerFeaturesFutureStub> {
    private ServerFeaturesFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getSupportedMethods(
        com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetSupportedMethodsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_SUPPORTED_METHODS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_SUPPORTED_METHODS:
          serviceImpl.getSupportedMethods((com.eventstore.dbclient.proto.shared.Shared.Empty) request,
              (io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getGetSupportedMethodsMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.eventstore.dbclient.proto.shared.Shared.Empty,
              com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>(
                service, METHODID_GET_SUPPORTED_METHODS)))
        .build();
  }

  private static abstract class ServerFeaturesBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ServerFeaturesBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ServerFeatures");
    }
  }

  private static final class ServerFeaturesFileDescriptorSupplier
      extends ServerFeaturesBaseDescriptorSupplier {
    ServerFeaturesFileDescriptorSupplier() {}
  }

  private static final class ServerFeaturesMethodDescriptorSupplier
      extends ServerFeaturesBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    ServerFeaturesMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ServerFeaturesGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ServerFeaturesFileDescriptorSupplier())
              .addMethod(getGetSupportedMethodsMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> db-client-java-5.4.4-sources.jar: com/eventstore/dbclient/proto/serverfeatures/ServerFeaturesGrpc.java <==
package com.eventstore.dbclient.proto.serverfeatures;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: serverfeatures.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class ServerFeaturesGrpc {

  private ServerFeaturesGrpc() {}

  public static final java.lang.String SERVICE_NAME = "event_store.client.server_features.ServerFeatures";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetSupportedMethods",
      requestType = com.eventstore.dbclient.proto.shared.Shared.Empty.class,
      responseType = com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty,
      com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod() {
    io.grpc.MethodDescriptor<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getGetSupportedMethodsMethod;
    if ((getGetSupportedMethodsMethod = ServerFeaturesGrpc.getGetSupportedMethodsMethod) == null) {
      synchronized (ServerFeaturesGrpc.class) {
        if ((getGetSupportedMethodsMethod = ServerFeaturesGrpc.getGetSupportedMethodsMethod) == null) {
          ServerFeaturesGrpc.getGetSupportedMethodsMethod = getGetSupportedMethodsMethod =
              io.grpc.MethodDescriptor.<com.eventstore.dbclient.proto.shared.Shared.Empty, com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetSupportedMethods"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.shared.Shared.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods.getDefaultInstance()))
              .setSchemaDescriptor(new ServerFeaturesMethodDescriptorSupplier("GetSupportedMethods"))
              .build();
        }
      }
    }
    return getGetSupportedMethodsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ServerFeaturesStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesStub>() {
        @java.lang.Override
        public ServerFeaturesStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesStub(channel, callOptions);
        }
      };
    return ServerFeaturesStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static ServerFeaturesBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingV2Stub>() {
        @java.lang.Override
        public ServerFeaturesBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesBlockingV2Stub(channel, callOptions);
        }
      };
    return ServerFeaturesBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ServerFeaturesBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesBlockingStub>() {
        @java.lang.Override
        public ServerFeaturesBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesBlockingStub(channel, callOptions);
        }
      };
    return ServerFeaturesBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ServerFeaturesFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<ServerFeaturesFutureStub>() {
        @java.lang.Override
        public ServerFeaturesFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new ServerFeaturesFutureStub(channel, callOptions);
        }
      };
    return ServerFeaturesFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetSupportedMethodsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service ServerFeatures.
   */
  public static abstract class ServerFeaturesImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return ServerFeaturesGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesStub
      extends io.grpc.stub.AbstractAsyncStub<ServerFeaturesStub> {
    private ServerFeaturesStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesStub(channel, callOptions);
    }

    /**
     */
    public void getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request,
        io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetSupportedMethodsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<ServerFeaturesBlockingV2Stub> {
    private ServerFeaturesBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetSupportedMethodsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<ServerFeaturesBlockingStub> {
    private ServerFeaturesBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods getSupportedMethods(com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetSupportedMethodsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service ServerFeatures.
   */
  public static final class ServerFeaturesFutureStub
      extends io.grpc.stub.AbstractFutureStub<ServerFeaturesFutureStub> {
    private ServerFeaturesFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ServerFeaturesFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new ServerFeaturesFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods> getSupportedMethods(
        com.eventstore.dbclient.proto.shared.Shared.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetSupportedMethodsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_SUPPORTED_METHODS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_SUPPORTED_METHODS:
          serviceImpl.getSupportedMethods((com.eventstore.dbclient.proto.shared.Shared.Empty) request,
              (io.grpc.stub.StreamObserver<com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getGetSupportedMethodsMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.eventstore.dbclient.proto.shared.Shared.Empty,
              com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.SupportedMethods>(
                service, METHODID_GET_SUPPORTED_METHODS)))
        .build();
  }

  private static abstract class ServerFeaturesBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ServerFeaturesBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.eventstore.dbclient.proto.serverfeatures.Serverfeatures.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ServerFeatures");
    }
  }

  private static final class ServerFeaturesFileDescriptorSupplier
      extends ServerFeaturesBaseDescriptorSupplier {
    ServerFeaturesFileDescriptorSupplier() {}
  }

  private static final class ServerFeaturesMethodDescriptorSupplier
      extends ServerFeaturesBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    ServerFeaturesMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ServerFeaturesGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ServerFeaturesFileDescriptorSupplier())
              .addMethod(getGetSupportedMethodsMethod())
              .build();
        }
      }
    }
    return result;
  }
}
